#ifndef TUNES_H
#define TUNES_H

#include "pitches.h"


namespace tunes
{


void playTune(uint16_t melody[], uint8_t durations[], int size) {
  for (int note = 0; note < size; note++) {
    //to calculate the note duration, take one second divided by the note type.
    //e.g. quarter note = 1000 / 4, eighth note = 1000/8, etc.
    int duration = 1000 / durations[note];
    tone(SPEAKERPIN, melody[note], duration);

    //to distinguish the notes, set a minimum time between them.
    //the note's duration + 30% seems to work well:
    int pauseBetweenNotes = duration * 1.30;
    delay(pauseBetweenNotes);
    
    //stop the tone playing:
    noTone(SPEAKERPIN);
  }
  
}

uint16_t tetrisMelody[] = {
  NOTE_E5, NOTE_B4, NOTE_C5, NOTE_D5, NOTE_C5, NOTE_B4,
  NOTE_A4, NOTE_A4, NOTE_C5, NOTE_E5, NOTE_D5, NOTE_C5,
  NOTE_B4, NOTE_C5, NOTE_D5, NOTE_E5,
  NOTE_C5, NOTE_A4, NOTE_A4, NOTE_A4, NOTE_B4, NOTE_C5,
};
uint8_t tetrisDurations[] = {
  4, 8, 8, 4, 8, 8,
  4, 8, 8, 4, 8, 8,
  4, 8, 4, 4,
  4, 4, 8, 4, 8, 8
};

uint16_t nokiaMelody[] = {
  NOTE_E5, NOTE_D5, NOTE_FS4, NOTE_GS4, 
  NOTE_CS5, NOTE_B4, NOTE_D4, NOTE_E4, 
  NOTE_B4, NOTE_A4, NOTE_CS4, NOTE_E4,
  NOTE_A4
};
uint8_t nokiaDurations[] = {
  8, 8, 4, 4,
  8, 8, 4, 4,
  8, 8, 4, 4,
  2
};

uint16_t ringtoneMelody[] = {
  NOTE_C5, NOTE_E5, NOTE_G5, NOTE_E5,
  NOTE_C6, NOTE_B5, NOTE_A5, NOTE_B5
};
uint8_t ringtoneDurations[] = {
  8, 8, 8, 8,
  4, 8, 8, 4
};

uint16_t caveMelody[] = {
  NOTE_A3, NOTE_C4, NOTE_E4, NOTE_D4,
  NOTE_F3, NOTE_G3, NOTE_E3, NOTE_A3,
  NOTE_G3, NOTE_B3, NOTE_D4, NOTE_C4,
  NOTE_A3, NOTE_F3, NOTE_E3, NOTE_A2
};
uint8_t caveDurations[] = {
  8, 8, 4, 8,
  8, 8, 4, 2,
  8, 8, 4, 8,
  8, 8, 4, 2
};

uint16_t desertMelody[] = {
  NOTE_A3, NOTE_B3, NOTE_C4, NOTE_A3,
  NOTE_G3, NOTE_A3, NOTE_B3, NOTE_A3,
  NOTE_C4, NOTE_D4, NOTE_C4, NOTE_B3,
  NOTE_A3, NOTE_G3, NOTE_A3
};
uint8_t desertDurations[] = {
  8, 8, 4, 8,
  8, 8, 4, 8,
  8, 8, 8, 8,
  4, 8, 2
};

uint16_t underwaterMelody[] = {
  NOTE_A3, NOTE_C4, NOTE_E4, NOTE_D4, NOTE_E4,
  NOTE_F3, NOTE_A3, NOTE_C4, NOTE_B3, NOTE_A3,
  NOTE_G3, NOTE_F3, NOTE_D4, NOTE_E4, NOTE_C4,
  NOTE_B3, NOTE_A3, NOTE_E4
};
uint8_t underwaterDurations[] = {
  8, 8, 8, 8, 4,
  8, 8, 8, 8, 4,
  8, 8, 8, 8, 4,
  8, 8, 2
};



uint16_t rickMelody[] = {
  NOTE_A4, REST, NOTE_B4, REST, NOTE_C5, REST, NOTE_A4, REST,
  NOTE_D5, REST, NOTE_E5, REST, NOTE_D5, REST,

  NOTE_G4, NOTE_A4, NOTE_C5, NOTE_A4, NOTE_E5, NOTE_E5, REST,
  NOTE_D5, REST,

  NOTE_G4, NOTE_A4, NOTE_C5, NOTE_A4, NOTE_D5, NOTE_D5, REST,
  NOTE_C5, REST, NOTE_B4, NOTE_A4, REST,

  NOTE_G4, NOTE_A4, NOTE_C5, NOTE_A4, NOTE_C5, NOTE_D5, REST,
  NOTE_B4, NOTE_A4, NOTE_G4, REST, NOTE_G4, REST, NOTE_D5, REST, NOTE_C5, REST,

  NOTE_G4, NOTE_A4, NOTE_C5, NOTE_A4, NOTE_E5, NOTE_E5, REST,
  NOTE_D5, REST,

  NOTE_G4, NOTE_A4, NOTE_C5, NOTE_A4, NOTE_G5, NOTE_B4, REST,
  NOTE_C5, REST, NOTE_B4, NOTE_A4, REST,

  NOTE_G4, NOTE_A4, NOTE_C5, NOTE_A4, NOTE_C5, NOTE_D5, REST,
  NOTE_B4, NOTE_A4, NOTE_G4, REST, NOTE_G4, REST, NOTE_D5, REST, NOTE_C5, REST,

  NOTE_C5, REST, NOTE_D5, REST, NOTE_G4, REST, NOTE_D5, REST, NOTE_E5, REST,
  NOTE_G5, NOTE_F5, NOTE_E5, REST,

  NOTE_C5, REST, NOTE_D5, REST, NOTE_G4, REST
};

uint8_t rickDurations[] = {
  8, 8, 8, 8, 8, 8, 8, 4,
  8, 8, 8, 8, 2, 2,

  8, 8, 8, 8, 2, 8, 8,
  2, 8,

  8, 8, 8, 8, 2, 8, 8,
  4, 8, 8, 8, 8,

  8, 8, 8, 8, 2, 8, 8,
  2, 8, 4, 8, 8, 8, 8, 8, 1, 4,

  8, 8, 8, 8, 2, 8, 8,
  2, 8,

  8, 8, 8, 8, 2, 8, 8,
  2, 8, 8, 8, 8,

  8, 8, 8, 8, 2, 8, 8,
  4, 8, 3, 8, 8, 8, 8, 8, 1, 4,

  2, 6, 2, 6, 4, 4, 2, 6, 2, 3,
  8, 8, 8, 8,

  2, 6, 2, 6, 2, 1
};
}
#endif
